==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Colores</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Colores</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_es.ts--
Ver gráficos</translatorcomment>
        <translation type="obsolete">Ver gráficos</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Fondo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--ignored colon--
--file: sketch_es.po--</translatorcomment>
        <translation>Retículo:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Retículo inactivo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origen</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Cero relativo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Rejilla</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta rejilla:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Selección</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">En primer lugar el color para la selección</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Color principal de la selección:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Utilice color secundaria de selección</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Color secundaria de selección:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Puntos de referencia:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Puntos de referencia secundaria:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Borde del cuadro de selección:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Cuadro de selección:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Cuadro de selección de captura:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Herramientas de forzar</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Etiqueta forzar cursor:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Herramientas info</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mediciones y etiquetas:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Herramientas de dibujo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Formas auxiliares:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Herramientas de zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Borde del cuadro de selección:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Retículo inactivo:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translatorcomment>--exact match--
--file: sketch_es.po--
Origen:</translatorcomment>
        <translation>Origen:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cero relativo:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Punto de referencia:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: sketch_es.po--
Meta cuadrícula
&amp;Meta cuadrícula</translatorcomment>
        <translation>Rejilla:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Meta rejilla:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuadro de zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: grassmods_es.po--</translatorcomment>
        <translation type="obsolete">Selección:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Borde del cuadro de selección:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuadro de selección:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuadro de selección de captura:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Formas auxiliares:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fondo de la etiqueta Información:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fuente de la etiqueta Información:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Herramientas de medición:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Colores</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Colores</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_es.ts--
Ver gráficos</translatorcomment>
        <translation type="obsolete">Ver gráficos</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Ver gráficos</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Fondo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--ignored colon--
--file: sketch_es.po--</translatorcomment>
        <translation>Retículo:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Retículo inactivo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origen</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Cero relativo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Rejilla</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta rejilla:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Selección</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">En primer lugar el color para la selección</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Color principal de la selección:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Utilice color secundaria de selección</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Color secundaria de selección:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Puntos de referencia:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Puntos de referencia secundaria:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Borde del cuadro de selección:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Cuadro de selección:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Cuadro de selección de captura:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Puntos de partida:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Puntos finales:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Herramientas de forzar</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Etiqueta forzar cursor:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Herramientas info</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mediciones y etiquetas:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Herramientas de dibujo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Formas auxiliares:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Herramientas de zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Borde del cuadro de selección:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Retículo inactivo:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translatorcomment>--exact match--
--file: sketch_es.po--
Origen:</translatorcomment>
        <translation>Origen:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cero relativo:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Punto de referencia:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: sketch_es.po--
Meta cuadrícula
&amp;Meta cuadrícula</translatorcomment>
        <translation>Rejilla:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Meta rejilla:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuadro de zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: grassmods_es.po--</translatorcomment>
        <translation type="obsolete">Selección:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Borde del cuadro de selección:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuadro de selección:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuadro de selección de captura:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Formas auxiliares:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fondo de la etiqueta Información:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fuente de la etiqueta Información:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Herramientas de medición:</translation>
    </message>
</context>
</TS>
